##
## Sample csh/tcsh .cshrc file
##
## It also can be used in tcsh.
##
## 2 Apr 1997 Choi Jun Ho <junker@jazz.snu.ac.kr>
##

# in case of non-interactive shell, most of things can be skipped
if ($?prompt) then
##
## some aliases
##

# show history
alias  h		'history 25'

# list jobs
alias  j		'jobs -l'

# ls
alias  la		'ls -a'
alias  lf		'ls -FA'
alias  ll		'ls -laFg |more'
alias  ls		'ls -F'

# NNTP-only tin
alias  tin		'tin -r'
# read newgroups only in ~/.newsrc
#alias  tin		'tin -r -n -q'

# easy popd
alias  popd		'popd \!*; cd .'

# delete backup files
alias  delbaks    	'rm #* *~ *.bak'

# launch hanemacs in favorite font
alias  hanemacs  	 'hanemacs -fn -schumacher-clean-bold-r-normal--16-160-75-75-c-80-iso8859-1 -hfn -kaist-iyagi-bold-r-normal--16-160-75-75-c-160-johabsh-1'

# in original hanterm, KSC5601-1987.0 fonts must be used with -ks
# not needed in autofont or XF8632 version
#alias   hanterm	   'hanterm -ks'

# launch kterm, japanese terminal
#alias  kterm	   	'setenv LANG ja_JP.EUC; \kterm'

# ztelnet
#alias  ztelnet	   	'ztelnet -8'

# to read hangul messages in HLaTeX-0.95 
#alias  latex      	'latex \!* | ~/bin/thmf'

# don't display unnecessary chars in a2ps variant
alias  a2ps	   	'a2ps -nv'
alias  h2ps	   	'h2ps -nv'
#alias  nh2ps		'nh2ps -nv -J -KHGraphic \!* | nh2ps_opt'

# ncftp 2.x is named as ncftp2 in FreeBSD
alias  ncftp      	'ncftp2'

##
## enviroment variables
##

# your usenet news folder 
setenv DOTDIR 		$HOME/News

# your news server
setenv NNTPSERVER 	news.snu.ac.kr
#setenv NNTPSERVER 	news.kornet.nm.kr

# your terminal type(not preferred)
#setenv TERM 		vt100

# to see hangul in less
#setenv LESS 		"-ficesr"
setenv  LESSCHARDEF 	"8bcccbcc18b95.33b95.b"

# manual search path
#setenv MANPATH 	/usr/share/man:/usr/openwin/man:/usr/local/man

# GNU info search path
#setenv INFOPATH 	/usr/share/info:/usr/local/info

# your favorite editor
setenv VISUAL  		/usr/bin/vi
#setenv VISUAL  	/usr/local/bin/helvis
#setenv	EDITOR		/usr/bin/ee
setenv	EDITOR		/usr/bin/vi
#setenv	EDITOR		/usr/local/bin/helvis

# your favorite pager
setenv	PAGER		more
#setenv	PAGER		less

# default block size
setenv	BLOCKSIZE	K

# when OpenWindoes(XView) is installed
setenv OPENWINHOME 	/usr/X11R6

# your locale(must be fully qualified name)
setenv LANG  ko_KR.EUC


set filec
set nohup
set history = 100
set savehist = 100
set mail = (/var/mail/$USER)
set path=(/bin /usr/local/bin /usr/X11R6/bin /usr/bin ~/bin /sbin /usr/sbin)
set ignoreeof

# your file creation mask
umask 022
# prevent making nasty core dumps
limit core 0

# to pass 8-bit char
stty -istrip -parenb cs8

##
## sh-dependent setup
##
if ($?tcsh) then
  # tcsh-only stuff
 
  # set prompt
  set prompt="%B%m%b:%~% "

  # enables auto-complete file listing
  set autolist

  # enables auto-expand
  set autoexpand

  # enables auto spell correction
  set autocorrect

  # kind of correction. cmd means command correction
  set correct=cmd

  # use ... instead of /<skipped> in %c prompt 
  set ellipsis

  # classify symbolic links.
  # > : link to directory
  # @ : link to file
  # & : non-exist destination
  set listlinks

  # setup complete file
  source ~/.complete 

  # setup keybindings
  # ^? is binded to backward-delete-char by default, so fix it
  bindkey '^?' backward-delete-word

  # C-w delete 'word'
  bindkey  backward-delete-word

  # M-j (M == meta key == ESC) rotates completion choices forward.
  bindkey '^[j' complete-word-fwd
  bindkey '^[k' complete-word-back

  # auto-magical history expansion by space key.
  # eg)   % man tcsh
  #       % vi .tcshrc
  #       % !m <space>
  #    -> % man tcsh
  bindkey ' ' magic-space

  # specify to not rebound to self-insert-command
  setenv  NOREBIND

else
  # traditional csh
  # an old-csh style prompt
  alias   cd     'cd \!*;set prompt="`hostname`:$cwd% "'
  cd
endif

else

# non-interactive shell
#
# set path only if not interactive shell.
# we don't need set it everytime we login, because .login sets correct path.

set path = (/sbin /bin /usr/sbin /usr/bin /usr/games /usr/local/bin /usr/X11R6/bin $HOME/bin)

endif
